/*
 * Segment 2 (KEx),  SWE 2.DE Statischer Import MIF
 * Copyright (C) 2007 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */


package de.bsvrz.kex.mif.kb;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.kex.mif.konfigdaten.ImportException;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.kbgen.ConfigAreaCreator;
import de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject;

/**
 * Realisiert das Modul Konfigurationsbereich der SWE.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */
public class MifKonfigurationsBereich implements MifKonfigurationsBereichInterface {

	/**
	 * Debug-Logger f&uuml;r Ausgaben.
	 */
	private static final Debug DEBUG = Debug.getLogger();

	/**
	 * Liste der erzeugten Konfigurationsobjekte.
	 */
	private List<ProxyConfigurationObject> konfigurationsObjekte = new LinkedList<ProxyConfigurationObject>();

	/**
	 * Dateiname der Konfigurationsbereichsdatei.
	 */
	private String dateiName;

	/**
	 * Konfigurationsverantwortlicher.
	 */
	private String kv;

	/**
	 * PID des Konfigurationsbereiches.
	 */
	private String pid;

	/**
	 * Name des Konfigurationsbereiches.
	 */
	private String name;

	/**
	 * Info des Konfigurationsbereiches.
	 */
	private String info;

	/**
	 * Datenverteiler-Verbindung.
	 */
	private ClientDavConnection dav;

	@Override
	public void addObjekt(final KonfigurationsObjekt objekt) {
		try {
			konfigurationsObjekte.addAll(objekt.getProxyObjekt(dav));
		} catch (final ImportException e) {
			MifKonfigurationsBereich.DEBUG.error(e.getMessage());
		}
	}

	/**
	 * L&ouml;scht die Liste der Konfigurationsobjekte.
	 */
	public void clear() {
		konfigurationsObjekte.clear();
	}

	@Override
	public void generiereXML() {
		final ConfigAreaCreator cac = new ConfigAreaCreator(new File(dateiName), pid, name, info, kv,
				konfigurationsObjekte);

		MifKonfigurationsBereich.DEBUG.info("Der Konfigurationsbereich '" + dateiName + "' (XML) wird erzeugt."); //$NON-NLS-1$

		cac.run();

		MifKonfigurationsBereich.DEBUG.info("Der Konfigurationsbereich '" + dateiName + "' (XML) wurde erzeugt."); //$NON-NLS-1$
	}

	@Override
	public void initialisiere(final ClientDavConnection davConnection, final String dateiNameKonfigurationsBereich,
			final String konfigurationsVerantwortlicher, final String konfigurationsBereichsPid,
			final String konfigurationsBereichsName, final String konfigurationsBereichsInfo) {

		this.dateiName = dateiNameKonfigurationsBereich;
		this.kv = konfigurationsVerantwortlicher;
		this.pid = konfigurationsBereichsPid;
		this.name = konfigurationsBereichsName;
		this.info = konfigurationsBereichsInfo;

		dav = davConnection;
	}
}
