/**
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:<br>
 * BitCtrl Systems GmbH<br>
 * Wei&szlig;enfelser Stra&szlig;e 67<br>
 * 04229 Leipzig<br>
 * Phone: +49 341-490670<br>
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.mif.vew;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.util.Arrays;
import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.border.LineBorder;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * Liste zur Selektion von Eintr&auml;gen.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 */
public class SelectionListe extends JScrollPane {

	/**
	 * Der PreselectionListsHandler verwaltet die Daten und aktualisiert die
	 * Listen.
	 */
	// private final PreselectionListsHandler _preselectionListsHandler;

	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	/** Diese Liste wird für den Listener benötigt. */
	private final List<ImportListener> _listenerList = new LinkedList<ImportListener>();

	int fontsize_i = 14;
	JList _list = new JList();

	/**
	 * Erzeugt eine neue Auswahlliste.
	 * 
	 * @param selectionmodel
	 *            Das zu verwendende Selectionmodell
	 */
	public SelectionListe(final int selectionmodel) {
		super();
		this.getViewport().setView(_list);
		setBorder(new LineBorder(Color.GRAY));
		setFont(new Font(null, 0, fontsize_i));
		// setSize(new Dimension(300, 300));
		setPreferredSize(new Dimension(200, 150));
		// this.setMinimumSize(new Dimension(10, 10));
		// this.setMaximumSize(new Dimension(10, 10));
		// _list.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
		_list.setSelectionMode(selectionmodel);
		_list.addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(final ListSelectionEvent e) {
				if (!e.getValueIsAdjusting()) {
					notifyListSelectionChanged();

				}
			}
		});

		_list.addMouseMotionListener(new MouseMotionListener() {
			@Override
			public void mouseDragged(final MouseEvent e) {
			}

			@Override
			public void mouseMoved(final MouseEvent e) {

			}
		});

		_list.addKeyListener(new KeyListener() {
			@Override
			public void keyPressed(final KeyEvent e) {
			}

			@Override
			public void keyReleased(final KeyEvent e) {
			}

			@Override
			public void keyTyped(final KeyEvent e) {
				// _atgList.ensureIndexIsVisible(_atgList.getSelectedIndex());
			}
		});
	}

	/** Gibt dem Listener Bescheid, ob eine Änderung eingetreten ist. */
	void notifyListSelectionChanged() {
		for (final ImportListener listener : _listenerList) {
			// listener.setObjects(objekte)
			listener.listSelectionChanged(this);
		}
	}

	/*
	 * (Kein Javadoc)
	 * 
	 * @see de.bsvrz.kex.mif.vew.ImportListener#setObjects(java.util.Collection)
	 */
	public void setObjects(final Collection<String> objekte) {
		_list.setListData(objekte.toArray());
	}

	public void addListener(final ImportListener listner) {
		_listenerList.add(listner);
	}

	public List<Object> getSelectedObjects() {
		return Arrays.asList(_list.getSelectedValues());
	}
}
